@@ -4,4 +4,6 @@ from firstimpression.api import nu_nl
 from firstimpression.api import traffic
 from firstimpression.api import request
 from firstimpression.api import insta
-from firstimpression.api import weather
\ No newline at end of file
+from firstimpression.api import weather
+from firstimpression.api import amber_alert
+from firstimpression.api import ams_airport
\ No newline at end of file
