@@ -3,7 +3,9 @@ import time
 import imghdr
 import shutil
 import requests
+from bs4 import BeautifulSoup
 from firstimpression.scala import install_content
+from firstimpression.api.request import request
 import xml.etree.ElementTree as ET
 
 
@@ -73,3 +75,11 @@ def xml_to_root(path):
     tree = ET.parse(path)
     root = tree.getroot()
     return root
+
+def list_files(url, extensions):
+    response = request(url).text
+    soup = BeautifulSoup(response, 'html.parser')
+    all_elements = [elem.get('href') for elem in soup.find_all('a')]
+    select_elements = [elem for elem in all_elements if '.' + elem.split('.')[-1] in extensions]
+    return select_elements
+
